@@ -24,6 +24,7 @@ OC.L10N.register(
     "Unstar article" : "Artículu non destacáu",
     "Keep article unread" : "Caltener artículu ensín lleer",
     "Remove keep article unread" : "Desaniciar artículu ensín lleer",
+    "Share" : "Share",
     "Username" : "Nome d'usuariu",
     "by" : "por",
     "from" : "Dende",
@@ -43,10 +44,9 @@ OC.L10N.register(
     "Refresh" : "Anovar",
     "Load next feed" : "Carga'l siguiente feed",
     "Load previous feed" : "Carga'l feed anterior",
-    "Load next folder" : "Carga'l siguiente direutoriu",
     "Load previous folder" : "Carga'l direutoriu anterior",
+    "Load next folder" : "Carga'l siguiente direutoriu",
     "Scroll to active navigation entry" : "Movese hasta la entrada de navegación activa",
-    "Focus search field" : "campu de gueta d'enfoque",
     "Mark current article's feed/folder read" : "Marcar tolos articulos actuales como lleíos",
     "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativu",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Instalar y configurar un actualizador más rápidu paralelu qu'utilice l'API d'actualización de l'aplicación Noticies",
