@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Forespørgslen mislykkedes, Nextcloud er i øjeblikket i vedligeholdelse tilstand!",
     "Unread articles" : "Ulæste artikler",
     "News" : "Nyheder",
+    "Shared with me" : "Delt med mig",
     "Use system cron for updates" : "Benyt system cron til opdateringer",
     "Purge interval" : "Oprydningsinterval",
     "Maximum read count per feed" : "Det maksimale antal læsninger per feed",
@@ -25,6 +26,7 @@ OC.L10N.register(
     "Unstar article" : "Fjern stjerne fra artiklen",
     "Keep article unread" : "Bevar artikel ulæst",
     "Remove keep article unread" : "Fjern \"bevar artikel ulæst\"",
+    "Share" : "Del",
     "Username" : "Brugernavn",
     "by" : "af",
     "from" : "fra",
@@ -45,10 +47,9 @@ OC.L10N.register(
     "Refresh" : "Opdatér",
     "Load next feed" : "Indlæs næste feed",
     "Load previous feed" : "Indlæs forrige feed",
-    "Load next folder" : "Indlæs næste mappe",
     "Load previous folder" : "Indlæs forrige mappe",
+    "Load next folder" : "Indlæs næste mappe",
     "Scroll to active navigation entry" : "Rul frem til aktive navigationspost",
-    "Focus search field" : "Fokuser søgefelt",
     "Mark current article's feed/folder read" : "Markér nuværende artikels feed/mappe som læst",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron tilstand opdaget! Dine feed vil ikke blive opdateret!",
     "How to set up the operating system cron" : "Sådan opsætter du cron i operativsystemet",
