@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
     "Unread articles" : "Μη αναγνωσμένα άρθρα",
     "News" : "Νέα",
+    "Shared with me" : "Διαμοιρασμένα με εμένα",
     "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
     "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
     "Purge interval" : "Διάστημα καθαρισμού",
@@ -35,7 +36,9 @@ OC.L10N.register(
     "Unstar article" : "Αναίρεση επισήμανσης με αστέρι",
     "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
     "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
+    "Share" : "Διαμοιρασμός",
     "Username" : "Όνομα χρήστη",
+    "No users found" : "Δεν βρέθηκαν χρήστες",
     "by" : "από",
     "from" : "από",
     "Play audio" : "Αναπαραγωγή ήχου",
@@ -55,10 +58,9 @@ OC.L10N.register(
     "Refresh" : "Ανανέωση ",
     "Load next feed" : "Φόρτωση επόμενης ροής",
     "Load previous feed" : "Φόρτωση προηγούμενης ροής",
-    "Load next folder" : "Φόρτωση επόμενου φακέλου",
     "Load previous folder" : "Φόρτωση προηγούμενου φακέλου",
+    "Load next folder" : "Φόρτωση επόμενου φακέλου",
     "Scroll to active navigation entry" : "Κύλιση στην ενεργή είσοδο πλοήγησης ",
-    "Focus search field" : "Εστίαση στο πεδίο αναζήτησης",
     "Mark current article's feed/folder read" : "Σημείωση της ροής/φακέλου του τρέχοντος άρθρου ως αναγνωσμένα",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
     "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
