@@ -23,6 +23,7 @@ OC.L10N.register(
     "Unstar article" : "Eemalda artiklilt täht",
     "Keep article unread" : "Hoia kui lugemata",
     "Remove keep article unread" : "Eemalda märgistus 'Hoia kui lugemata'",
+    "Share" : "Jaga",
     "Username" : "Kasutajanimi",
     "by" : "lisas",
     "from" : "kohast",
@@ -43,9 +44,8 @@ OC.L10N.register(
     "Refresh" : "Värskenda",
     "Load next feed" : "Laadi järgmine voog",
     "Load previous feed" : "Kaadi eelmine voog",
-    "Load next folder" : "Laadi järgmine kataloog",
     "Load previous folder" : "Laadi eelmine kataloog",
-    "Focus search field" : "Fokuseeri otsingulahter",
+    "Load next folder" : "Laadi järgmine kataloog",
     "Mark current article's feed/folder read" : "Märgi praegused artikli vood/kaustad loetuks",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax või webcron aktiveeritud! Su voogusid ei uuendata!",
     "How to set up the operating system cron" : "Kuidas seadistada operatsioonisüsteemi ajastatud tegevust",
