@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Produciuse un fallo na solicitude, Nexcloud esta actualmente en modo mantemento!",
     "Unread articles" : "Artigos sen ler",
     "News" : "Novas",
+    "Shared with me" : "Compartido comigo",
     "An RSS/Atom feed reader" : "Un lector de fontes RSS/Atom",
     "Use system cron for updates" : "Use o cron do sistema para as actualizacións",
     "Purge interval" : "Intervalo de depuración",
@@ -35,7 +36,9 @@ OC.L10N.register(
     "Unstar article" : "Desmarcar artigo",
     "Keep article unread" : "Conservar o artigo como non lido",
     "Remove keep article unread" : "Retirar a marca de artigo sen ler",
+    "Share" : "Compartir",
     "Username" : "Nome de usuario",
+    "No users found" : "Non se atoparon usuarios",
     "by" : "por",
     "from" : "dende",
     "Play audio" : "Reproducir son",
@@ -55,10 +58,9 @@ OC.L10N.register(
     "Refresh" : "Actualizar",
     "Load next feed" : "Cargar a seguinte fonte",
     "Load previous feed" : "Cargar a fonte anterior",
-    "Load next folder" : "Cargar o seguinte cartafol",
     "Load previous folder" : "Cargar o cartafol anterior",
+    "Load next folder" : "Cargar o seguinte cartafol",
     "Scroll to active navigation entry" : "Desprazar ata a entrada de navegación activa",
-    "Focus search field" : "Campo de busca en foco",
     "Mark current article's feed/folder read" : "Marcar o actual artigo de fonte/cartafol como lido",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Detectouse o modo Ajax ou webcron! As súas fontes non van ser actualizadas!",
     "How to set up the operating system cron" : "Cómo configurar o cron do sistema operativo",
