@@ -24,6 +24,7 @@ OC.L10N.register(
     "Unstar article" : "Hapus bintang artikel",
     "Keep article unread" : "Tandai artikel belum dibaca",
     "Remove keep article unread" : "Hapus tanda artikel belum dibaca",
+    "Share" : "Bagikan",
     "Username" : "Nama pengguna",
     "by" : "oleh",
     "from" : "dari",
@@ -44,10 +45,9 @@ OC.L10N.register(
     "Refresh" : "Segarkan",
     "Load next feed" : "Muat feed berikutnya",
     "Load previous feed" : "Muat feed sebelumnya",
-    "Load next folder" : "Muat folder berikutnya",
     "Load previous folder" : "Muat folder sebelumnya",
+    "Load next folder" : "Muat folder berikutnya",
     "Scroll to active navigation entry" : "Gulir ke entri navigasi aktif",
-    "Focus search field" : "Kolom pencarian terfokus",
     "Mark current article's feed/folder read" : "Tandai feed/folder artikel saat ini telah dibaca",
     "How to set up the operating system cron" : "Bagaimana cara menyetel cron sistem operasi",
     "Install and set up a faster parallel updater that uses the News app's update API" : "Pasang dan atur pembaruan paralel yang lebih cepat yang menggunakan API pembaruan aplikasi Berita",
