@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Fyrirspurn brást, Nextcloud er núna í viðhaldsham.",
     "Unread articles" : "Ólesnar greinar",
     "News" : "Fréttir",
+    "Shared with me" : "Deilt með mér",
     "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
     "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
     "Purge interval" : "Millibil förgunar",
@@ -35,6 +36,7 @@ OC.L10N.register(
     "Unstar article" : "Taka stjörnugjöf af grein",
     "Keep article unread" : "Halda greininni sem ólesinni",
     "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
+    "Share" : "Deila",
     "Username" : "Notandanafn",
     "by" : "eftir",
     "from" : "frá",
@@ -55,10 +57,9 @@ OC.L10N.register(
     "Refresh" : "Endurlesa",
     "Load next feed" : "Hlaða inn næsta streymi",
     "Load previous feed" : "Hlaða inn fyrra streymi",
-    "Load next folder" : "Hlaða inn næstu möppu",
     "Load previous folder" : "Hlaða inn fyrri möppu",
+    "Load next folder" : "Hlaða inn næstu möppu",
     "Scroll to active navigation entry" : "Skruna á virka færslu í flakki",
-    "Focus search field" : "Færa virkni í leitarreitinn",
     "Mark current article's feed/folder read" : "Merkja streymi/möppu núverandi greinar sem lesið",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
     "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
