@@ -7,8 +7,11 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "トークンまたはアプリが無効になりました！ページを再読込してください！",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "内部サーバーエラー！追加情報については、あなたのdata/nextcloud.logファイルをチェックしてください！",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "リクエストが失敗しました。Nextcloudは現在メンテナンスモードです。",
+    "News feeds" : "ニューズフィード",
     "Unread articles" : "未読の記事",
     "News" : "ニュース",
+    "News folders" : "ニューズフォルダー",
+    "Shared with me" : "私と共有",
     "An RSS/Atom feed reader" : "RSS/Atom フィードリーダー",
     "Use system cron for updates" : "更新のためにOSのcronを使用",
     "Purge interval" : "パージ周期",
@@ -28,7 +31,11 @@ OC.L10N.register(
     "Unstar article" : "スターなしの記事",
     "Keep article unread" : "記事を未読のままにする",
     "Remove keep article unread" : "記事の未読保持を解除",
+    "Share" : "共有",
+    "Share with users" : "ユーザーと共有",
     "Username" : "ユーザー名",
+    "No users found" : "ユーザーが見つかりません",
+    "Share on social media" : "SNSで共有",
     "by" : "by",
     "from" : "開始",
     "Play audio" : "音楽を再生",
@@ -48,10 +55,9 @@ OC.L10N.register(
     "Refresh" : "同期",
     "Load next feed" : "次のフィードを読み込む",
     "Load previous feed" : "前のフィードを読み込む",
-    "Load next folder" : "次のフォルダーを読み込む",
     "Load previous folder" : "前のフォルダーを読み込む",
+    "Load next folder" : "次のフォルダーを読み込む",
     "Scroll to active navigation entry" : "アクティブなナビゲーションエントリーにスクロール",
-    "Focus search field" : "検索フィールドにフォーカス",
     "Mark current article's feed/folder read" : "現在の記事のフィード/フォルダーを既読にする",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax か Web cron モードになっています。フィードは自動的に更新されません。",
     "How to set up the operating system cron" : "OSのcronのやり方",
