@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "요청이 실패했습니다. Nextcloud가 현재 관리 모드입니다!",
     "Unread articles" : "읽지 않은 글",
     "News" : "뉴스",
+    "Shared with me" : "나와 공유됨",
     "An RSS/Atom feed reader" : "RSS/Atom 피드 리더",
     "Use system cron for updates" : "시스템 cron으로 업데이트",
     "Purge interval" : "비우기 주기",
@@ -26,6 +27,7 @@ OC.L10N.register(
     "Unstar article" : "글에서 별표 떼기",
     "Keep article unread" : "읽지 않은 상태로 유지",
     "Remove keep article unread" : "읽지 않은 상태로 유지하지 않음",
+    "Share" : "공유",
     "Username" : "사용자 이름",
     "by" : "작성:",
     "from" : "원본 사이트:",
@@ -46,10 +48,9 @@ OC.L10N.register(
     "Refresh" : "새로 고침",
     "Load next feed" : "다음 피드 불러오기",
     "Load previous feed" : "이전 피드 불러오기",
-    "Load next folder" : "다음 폴더 불러오기",
     "Load previous folder" : "이전 폴더 불러오기",
+    "Load next folder" : "다음 폴더 불러오기",
     "Scroll to active navigation entry" : "활성 탐색 항목으로 스크롤",
-    "Focus search field" : "검색 필드에 초점 맞추기",
     "Mark current article's feed/folder read" : "현재 글이 속한 피드/폴더를 읽은 것으로 표시",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax 및 웹 cron 모드가 감지되었습니다! 피드를 업데이트하지 않습니다!",
     "How to set up the operating system cron" : "운영 체제 cron 설정 방법",
