@@ -8,6 +8,7 @@ OC.L10N.register(
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Iekšēja servera kļūda! Lūdzu pārbaudiet data/nextcloud.log papildus informācijai!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pieprasījums neizdevās, Nextcloud pašlaik darbojas uzturēšanas režīmā!",
     "Unread articles" : "Nelasītie raksti",
+    "Shared with me" : "Koplietots ar mani",
     "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
     "Purge interval" : "Iztīrīšanas intervāls",
     "Maximum redirects" : "Maksimāli pieļaujamais pārsūtīšanu skaits",
@@ -15,6 +16,7 @@ OC.L10N.register(
     "Download" : "Lejupielādēt",
     "Close" : "Aizvērt",
     "Open website" : "Atvērt vietni",
+    "Share" : "Koplietot",
     "Username" : "Lietotājvārds",
     "by" : "līdz",
     "from" : "no",
@@ -26,8 +28,8 @@ OC.L10N.register(
     "right" : "pa labi",
     "left" : "pa kreisi",
     "Refresh" : "Atsvaidzināt",
-    "Load next folder" : "Ielādēt nākamo mapi",
     "Load previous folder" : "Ielādēt iepriekšējo mapi",
+    "Load next folder" : "Ielādēt nākamo mapi",
     "Subscribe" : "Abonēt",
     "Web address" : "Tīmekļa adrese",
     "Feed exists already!" : "Plūsma jau eksistē!",
