@@ -5,6 +5,8 @@ OC.L10N.register(
     "Saved" : "Хадгалах",
     "Download" : "Татах",
     "Close" : "Хаах",
+    "Share" : "Түгээх",
+    "Username" : "Хэрэглэгчийн нэр",
     "from" : "тэндээс",
     "Play audio" : "Аудио тоглуулах",
     "Download audio" : "Аудиог татаж авах",
@@ -19,9 +21,8 @@ OC.L10N.register(
     "Refresh" : "Сэргээх",
     "Load next feed" : "Дараагийн тэжээлийг ачаална уу",
     "Load previous feed" : "Өмнөх тэжээлийг ачаална уу",
-    "Load next folder" : "Дараагийн хавтасыг ачаална уу",
     "Load previous folder" : "Өмнөх хавтсыг ачаална уу",
-    "Focus search field" : "Хайлтын талбар дээр анхаарлаа хандуул",
+    "Load next folder" : "Дараагийн хавтасыг ачаална уу",
     "How to set up the operating system cron" : "Үйлдлийн системийн cron-г хэрхэн тохируулах талаар",
     "Subscribe" : "Захиалга",
     "Web address" : "Вэб хаяг",
@@ -31,7 +32,6 @@ OC.L10N.register(
     "Folder name" : "Хавтасны нэр",
     "Go back" : "Буцах",
     "Credentials" : "Итгэмжлэл",
-    "Username" : "Хэрэглэгчийн нэр",
     "Password" : "Нууц үг",
     "New Folder" : "Шинэ хавтас",
     "Create" : "Үүсгэх",
