@@ -7,7 +7,9 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Nøkkel utløpt eller app ikke aktivert! Last siden på nytt!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Intern feil! Sjekk dine data/nextcloud.log fil for mer informasjon.",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Forespørsel mislyktes, Nextcloud er i vedlikeholdsmodus!",
+    "Unread articles" : "Uleste artikler",
     "News" : "Nyheter",
+    "Shared with me" : "Delt med meg",
     "An RSS/Atom feed reader" : "En RSS/Atom-leser",
     "Use system cron for updates" : "Bruk system-cron for oppdateringer",
     "Purge interval" : "Opprenskingsinterval",
@@ -25,6 +27,8 @@ OC.L10N.register(
     "Unstar article" : "Fjern merking av artikkelen",
     "Keep article unread" : "Behold artikkelen ulest",
     "Remove keep article unread" : "Fjern behold artikkelen ulest",
+    "Share" : "Del",
+    "Username" : "Brukernavn",
     "by" : "av",
     "from" : "fra",
     "Play audio" : "Spill lyd",
@@ -44,10 +48,9 @@ OC.L10N.register(
     "Refresh" : "Oppdater",
     "Load next feed" : "Last neste strøm",
     "Load previous feed" : "Last forrige strøm",
-    "Load next folder" : "Last neste mappe",
     "Load previous folder" : "Last forrige mappe",
+    "Load next folder" : "Last neste mappe",
     "Scroll to active navigation entry" : "Bla til aktiv navigeringspost",
-    "Focus search field" : "Gi fokus til søkefeltet",
     "Mark current article's feed/folder read" : "Merk denne artikkelens strøm/mappe som lest",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron-metode påvist! Strømmene dine vil ikke bli oppdaterte!",
     "How to set up the operating system cron" : "Hvordan sette opp operativsystemets Cron",
@@ -63,7 +66,6 @@ OC.L10N.register(
     "Folder exists already!" : "Mappe finnes allerede!",
     "Credentials" : "Påloggingsdetaljer",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Detaljer for HTTP Basic Auth må lagres ukryptert! Alle med tilgang til serveren eller databasen vil være i stand til å nå dem!",
-    "Username" : "Brukernavn",
     "Password" : "Passord",
     "New Folder" : "Ny mappe",
     "Create" : "Opprett",
@@ -90,7 +92,6 @@ OC.L10N.register(
     "Deleted folder" : "Slettet mappe",
     "Undo delete folder" : "Angre sletting av mappe",
     "Starred" : "Merket",
-    "Unread articles" : "Uleste artikler",
     "All articles" : "Alle artikler",
     "Settings" : "Innstillinger",
     "Disable mark read through scrolling" : "Slå av merk som lest ved blading",
