@@ -21,6 +21,7 @@ OC.L10N.register(
     "Unstar article" : "Desespingolar l'article",
     "Keep article unread" : "Marcar l'article coma pas legit",
     "Remove keep article unread" : "Marcar l'article coma legit",
+    "Share" : "Partejar",
     "Username" : "Identificant",
     "by" : "per",
     "from" : "de",
@@ -41,10 +42,9 @@ OC.L10N.register(
     "Refresh" : "Refrescar",
     "Load next feed" : "Cargar lo flux seguent",
     "Load previous feed" : "Cargar lo flux precedent",
-    "Load next folder" : "Cargar lo dorsièr seguent",
     "Load previous folder" : "Cargar lo dorsièr precedent",
+    "Load next folder" : "Cargar lo dorsièr seguent",
     "Scroll to active navigation entry" : "Anar vers lo camp de navigacion actif",
-    "Focus search field" : "Centrar sul camp de recèrca",
     "Mark current article's feed/folder read" : "Marcar coma legit lo flux / lo repertòri de l'article en cours",
     "How to set up the operating system cron" : "Cossí configurar lo cron del sistèma operatiu",
     "Subscribe" : "S'abonar",
