@@ -21,6 +21,7 @@ OC.L10N.register(
     "Unstar article" : "ยกเลิกติดดาวบทความ",
     "Keep article unread" : "ตั้งเป็นยังไม่ได้อ่านบทความ",
     "Remove keep article unread" : "ลบการตั้งเป็นยังไม่ได้อ่านบทความ",
+    "Share" : "แชร์",
     "Username" : "ชื่อผู้ใช้",
     "by" : "โดย",
     "from" : "จาก",
@@ -41,10 +42,9 @@ OC.L10N.register(
     "Refresh" : "รีเฟรช",
     "Load next feed" : "โหลดฟีดถัดไป",
     "Load previous feed" : "โหลดฟีดก่อนหน้านี้",
-    "Load next folder" : "โหลดโฟลเดอร์ถัดไป",
     "Load previous folder" : "โหลดโฟลเดอร์ก่อนหน้า",
+    "Load next folder" : "โหลดโฟลเดอร์ถัดไป",
     "Scroll to active navigation entry" : "เลื่อนเพื่อใช้งานรายการนำทาง",
-    "Focus search field" : "โฟกัสช่องค้นหา",
     "Mark current article's feed/folder read" : "ทำเครื่องหมายอ่านบทความปัจจุบัน ฟีด/โฟลเดอร์",
     "How to set up the operating system cron" : "วิธีการตั้งค่าระบบปฏิบัติการ cron",
     "Install and set up a faster parallel updater that uses the News app's update API" : "ติดตั้งและตั้งค่าการอัพเดทขนานที่เร็วขึ้นน้้นใช้ แอพฯข่าวการอัพเดท API",
