@@ -7,8 +7,10 @@
  *
  * @author    Alessandro Cosentino <cosenal@gmail.com>
  * @author    Bernhard Posselt <dev@bernhard-posselt.com>
+ * @author    Paul Tirk <paultirk@paultirk.com>
  * @copyright 2012 Alessandro Cosentino
  * @copyright 2012-2014 Bernhard Posselt
+ * @copyright 2020 Paul Tirk
  */
 
 namespace OCA\News\Db;
@@ -65,6 +67,10 @@ class Item extends Entity implements IAPI, \JsonSerializable
     protected $starred = false;
     /** @var string|null */
     protected $categoriesJson;
+    /** @var string|null */
+    protected $sharedBy;
+    /** @var string|null */
+    protected $sharedByDisplayName;
 
     public function __construct()
     {
@@ -88,6 +94,40 @@ class Item extends Entity implements IAPI, \JsonSerializable
         $this->addType('unread', 'boolean');
         $this->addType('starred', 'boolean');
         $this->addType('categoriesJson', 'string');
+        $this->addType('sharedBy', 'string');
+    }
+
+    public function __clone()
+    {
+        $this->setId(null);
+
+        /**
+         * Removes 'id' from updatedFields; this will avoid explicitly
+         * inserting the value NULL into the DB, and will instead allow a new
+         * id to be generated.
+         * */
+        $this->resetUpdatedFields();
+        $this->markFieldUpdated('contentHash');
+        $this->markFieldUpdated('guidHash');
+        $this->markFieldUpdated('guid');
+        $this->markFieldUpdated('url');
+        $this->markFieldUpdated('title');
+        $this->markFieldUpdated('author');
+        $this->markFieldUpdated('pubDate');
+        $this->markFieldUpdated('body');
+        $this->markFieldUpdated('enclosureMime');
+        $this->markFieldUpdated('enclosureLink');
+        $this->markFieldUpdated('mediaThumbnail');
+        $this->markFieldUpdated('mediaDescription');
+        $this->markFieldUpdated('feedId');
+        $this->markFieldUpdated('lastModified');
+        $this->markFieldUpdated('searchIndex');
+        $this->markFieldUpdated('rtl');
+        $this->markFieldUpdated('fingerprint');
+        $this->markFieldUpdated('unread');
+        $this->markFieldUpdated('starred');
+        $this->markFieldUpdated('categoriesJson');
+        $this->markFieldUpdated('sharedBy');
     }
 
     /**
@@ -283,6 +323,16 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this->unread;
     }
 
+    public function getSharedBy(): ?string
+    {
+        return $this->sharedBy;
+    }
+
+    public function getSharedByDisplayName(): ?string
+    {
+        return $this->sharedByDisplayName;
+    }
+
     /**
      * @return null|string
      */
@@ -325,7 +375,9 @@ class Item extends Entity implements IAPI, \JsonSerializable
             'rtl' => $this->getRtl(),
             'intro' => $this->getIntro(),
             'fingerprint' => $this->getFingerprint(),
-            'categories' => $this->getCategories()
+            'categories' => $this->getCategories(),
+            'sharedBy' => $this->getSharedBy(),
+            'sharedByDisplayName' => $this->getSharedByDisplayName()
         ];
     }
 
@@ -507,6 +559,25 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this;
     }
 
+    public function setSharedBy(string $sharedBy = null): self
+    {
+        if ($this->sharedBy !== $sharedBy) {
+            $this->sharedBy = $sharedBy;
+            $this->markFieldUpdated('sharedBy');
+        }
+
+        return $this;
+    }
+
+    public function setSharedByDisplayName(string $sharedByDisplayName = null): self
+    {
+        if ($this->sharedByDisplayName !== $sharedByDisplayName) {
+            $this->sharedByDisplayName = $sharedByDisplayName;
+        }
+
+        return $this;
+    }
+
     public function setUnread(bool $unread): self
     {
         if ($this->unread !== $unread) {
@@ -574,6 +645,36 @@ class Item extends Entity implements IAPI, \JsonSerializable
         ];
     }
 
+    public function toAPI2(bool $reduced = false): array
+    {
+        if ($reduced) {
+            return [
+                'id' => $this->getId(),
+                'isUnread' => $this->isUnread(),
+                'isStarred' => $this->isStarred()
+            ];
+        }
+
+        return [
+            'id' => $this->getId(),
+            'url' => $this->getUrl(),
+            'title' => $this->getTitle(),
+            'author' => $this->getAuthor(),
+            'publishedAt' => date('c', $this->getPubDate()),
+            'lastModifiedAt' => date('c', $this->cropApiLastModified()),
+            'enclosure' => [
+                'mimeType' => $this->getEnclosureMime(),
+                'url' => $this->getEnclosureLink()
+            ],
+            'body' => $this->getBody(),
+            'feedId' => $this->getFeedId(),
+            'isUnread' => $this->isUnread(),
+            'isStarred' => $this->isStarred(),
+            'fingerprint' => $this->getFingerprint(),
+            'contentHash' => $this->getContentHash()
+        ];
+    }
+
     /**
      * Format for exporting.
      *
