@@ -18,6 +18,7 @@ use Favicon\Favicon;
 use FeedIo\Feed\ItemInterface;
 use FeedIo\FeedInterface;
 use FeedIo\FeedIo;
+use FeedIo\Reader\ReadErrorException;
 use GuzzleHttp\Client;
 use GuzzleHttp\Exception\RequestException;
 use GuzzleHttp\Exception\ConnectException;
@@ -116,7 +117,7 @@ class FeedFetcher implements IFeedFetcher
     ): array {
         $url2 = new Net_URL2($url);
         if (!is_null($user) && trim($user) !== '') {
-            $url2->setUserinfo(urlencode($user), urlencode($password));
+            $url2->setUserinfo(rawurlencode($user), rawurlencode($password));
         }
         $url = $url2->getNormalizedURL();
         $this->reader->resetFilters();
@@ -233,6 +234,9 @@ class FeedFetcher implements IFeedFetcher
         $item = new Item();
         $item->setUnread(true);
         $item->setUrl($parsedItem->getLink());
+        if ($parsedItem->getPublicId() == null) {
+            throw new ReadErrorException("Malformed feed: item has no GUID");
+        }
         $item->setGuid($parsedItem->getPublicId());
         $item->setGuidHash(md5($item->getGuid()));
 
