@@ -24,10 +24,7 @@ interface IFeedFetcher
      * Fetch feed content.
      *
      * @param  string      $url           remote url of the feed
-     * @param  boolean     $favicon       if the favicon should also be fetched, defaults to true
-     * @param  string|null $lastModified  a last modified value from an http header defaults to false.
-     *                                    If lastModified matches the http header from the feed no results are fetched
-     * @param  bool      $fullTextEnabled If true use a scraper to download the full article
+     * @param  bool        $fullTextEnabled If true use a scraper to download the full article
      * @param  string|null $user          if given, basic auth is set for this feed
      * @param  string|null $password      if given, basic auth is set for this feed. Ignored if user is empty
      *
@@ -38,8 +35,6 @@ interface IFeedFetcher
      */
     public function fetch(
         string $url,
-        bool $favicon,
-        ?string $lastModified,
         bool $fullTextEnabled,
         ?string $user,
         ?string $password
